@@ -1,5 +1,5 @@
 package Net::Twitter::Core;
-use 5.8.1;
+use 5.008001;
 use Moose;
 use Carp;
 use JSON::Any qw/XS DWIW JSON/;
@@ -11,7 +11,7 @@ use namespace::autoclean;
 with 'MooseX::Traits';
 
 # use *all* digits for fBSD ports
-our $VERSION = '3.00000';
+our $VERSION = '3.01000_01';
 
 $VERSION = eval $VERSION; # numify for warning-free dev releases
 
@@ -73,20 +73,25 @@ sub _parse_result {
     my ($self, $res) = @_;
 
     # workaround for Laconica API returning bools as strings
+    # (Fixed in Laconi.ca 0.7.4)
     my $content = $res->content;
     $content =~ s/^"(true|false)"$/$1/;
 
-    my $obj = $self->_from_json($content);
+    # some JSON backends don't handle booleans correctly
+    # TODO: move this fix to JSON::Any
+    my $obj = $content eq 'true'  ? 1
+            : $content eq 'false' ? ''
+            : $self->_from_json($content);
 
     # Twitter sometimes returns an error with status code 200
     if ( $obj && ref $obj eq 'HASH' && exists $obj->{error} ) {
         die Net::Twitter::Error->new(twitter_error => $obj, http_response => $res);
     }
 
-    return $obj if $res->is_success && $obj;
+    return $obj if $res->is_success && defined $obj;
 
     my $error = Net::Twitter::Error->new(http_response => $res);
-    $error->twitter_error($obj) if $obj;
+    $error->twitter_error($obj) if ref $obj;
 
     die $error;
 }
